battle_sorters // these objects sort out battles, so it should only be deleted when the battle ends
	parent_type = /obj
	var

		mob/A // player one is A, while player 2 is B (P1 would be you, and P2 would be the monster)
		mob/B

	New(location, mob/a, mob/b)
		..()
		src.A = a
		src.B = b
		if(A&&B)              // if they are both there, start the battle
			StartBattle(A,B)
		StartChecking(A, B)


	proc
		StartChecking(mob/A, mob/B)   // this procedure checks if the people logged out of the battle or just
			spawn while(src)          // disappeared for some reason
				if(!A) LogOutBattle(A, B)
				else if(!B) LogOutBattle(B, A)
				sleep(25)				// we really don't need to loop it frequently, because it isn't really showable

		StartBattle(mob/A, mob/B)
			if(A.agi==B.agi)
/*					// removed as of version 2, thanks Crispy
				var/list/Rand = list(A, B)
				var/a = rand(1,2)
				while(a--)
					Rand.Swap(1,2)
*/
				if(prob(50)) // if a 1/2 chance is come
					var/tempvar = A // save a temporary variable for A
					A = B           // and swap ahead
					B = tempvar     // and restore the A to the B, making a successful swap
				EngageBattle(A, B)  // let the battle begin
			else
				if(A.agi > B.agi) // the faster, the better
					EngageBattle(A, B)
				else
					EngageBattle(B, A) // early bird gets to kill first


		EngageBattle(mob/A, mob/B)
			if(A.pdefence) // defending only lasts one turn
				A << "You stop defending."
				B << "[A] stops defending."
				A.pdefence = 0
			if(A.mdefence)
				A << "Your magic barrier disappears."
				B << "[A]'s magic barrier dissapears."
				A.mdefence = 0

			if(A.client) // if somebody is posessing A, let them control themselves

				var/list/commands = list("Fight","Item","Run")

				var/command = input(A, "Please select a command.","Command?") in commands // Base commands to use from
				switch(command)
					if("Fight")
						FightBattle(A, B)

					if("Item")
						var/list/L = A.contents
						if(L.len)
							var/item/I = input(A, "Pick an item to use","Item") in L + "Back"
							if(I=="Back")
								EngageBattle(A, B)
							else
								I.BattleUse(A)

							EngageBattle(B, A) // your turn is done, start the battle again, except backwards.


						else
							A << "You do not have any items to use."
							EngageBattle(A, B)

					if("Run")
						RunFromBattle(A, B)
			else // otherwise, do the monster intelligence
				MonsterBattle(A, B)

		FightBattle(mob/A, mob/B)

			var/list/commands = list("Attack","Skill","Defend","Wait")
			var/command = input(A, "Please select a command.","Command?") in commands
			switch(command)
				if("Attack")
					A.attack(B)
					if(B.DeathCheck(A))
						EndBattle(A, B, "win")
					else
						EngageBattle(B, A)


				if("Skill")
					var/list/L = A.skills
					if(L.len)
						var/battle/battleskill/I = input(A, "Pick a skill to use","Skill") in L + "Back"
						if(I=="Back")
							EngageBattle(A, B)
						else
							var/path = I.skillpath
							call(A,path)(B)			// the call() procedure saves the day so there is no long if() tree
							if(B.DeathCheck(A))     // if they're dead, stop the battle
								EndBattle(A, B, "win")
							else
								EngageBattle(B, A) // otherwise, keep on going


					else
						A << "You don't have any skills to use."
						FightBattle(A, B)

				if("Defend")
					A << "You start to defend."
					B << "[A] starts to defend."
					A.pdefence = 50 // half damage next turn
					sleep(10)
					EngageBattle(B, A)


				if("Wait")
					A << "You decide to wait the turn."
					B << "[A] decides to wait the turn."
					sleep(10)
					EngageBattle(B, A)

		MonsterBattle(mob/A, mob/B) // fun monster AI

			if(A.hp<=A.maxhp/4) // if the monster is low on HP
				var/list/L = A.skills // get the skills list
				for(var/battle/battleskill/item in L) // remove all non-support items
					if(!item.supportuse)
						L -= item
				if(L.len) // if there are any support skills
					var/battle/battleskill/I = pick(L) // use a random one
					var/path = I.skillpath
					call(A,path)(B)
					if(B.DeathCheck(A))
						EndBattle(A, B, "win")
					else
						EngageBattle(B, A)
				else // otherwise, the monster will attempt to run
					RunFromBattle(A, B)

			else // if they are all alright
				var/list/L = A.skills
				for(var/battle/battleskill/item in L)
					if(item.supportuse) // remove all support spells.  no need for any of them.
						L -= item
				if(L.len) // check if they have any
					var/battle/battleskill/I = pick(L)
					var/path = I.skillpath
					call(A,path)(B)
					if(B.DeathCheck(A))
						EndBattle(A, B, "win")
					else
						EngageBattle(B, A)
				else // otherwise attack normally
					A.attack(B)
					if(B.DeathCheck(A))
						EndBattle(A, B, "win")
					else
						EngageBattle(B, A)









		RunFromBattle(mob/A, mob/B)
			var/chance
			var/maxchance = 5
			A << "You attempt to run away..."
			B << "[A] attempts to run away..."

			if(A.agi >= B.agi) // a bigger chance of running if A's agility is faster than B's
				chance = rand(4,7)
			else
				chance = rand(3,6)

			spawn(10)
				if(chance>=maxchance)
					A << "You run away safely."
					B << "[A] runs away to safety."
					EndBattle(A,B,"run") // end the battle
				else
					A << "You are blocked by [B]"
					B << "[A] is blocked by you."
					EngageBattle(B, A) // redo the battle, except B starting first.



		EndBattle(mob/A, mob/B, status) // A is the winner, B is the loser, and the status, is obviously the status!
			A.loc = locate(A.lastx,A.lasty,A.lastz) // rejuvinate their original location
			A.inbattle = 0
			A.lock = 0
			B.loc = locate(B.lastx,B.lasty,B.lastz) // B is most likely a monster, but if it isn't, this will save some time
			B.inbattle = 0							// in the other if procedures
			B.lock = 0
			switch(status)
				if("win")
					world << "<b>[A] has won the battle against [B]</b>"
					B.Regenerate()
					B.Relocate()
					B.monstermove = null // the loser has its monstermove set back to null
				if("draw")
					world << "<b>[A] has drawed the battle against [B]</b>"
					A.Regenerate()
					B.Regenerate()
					A.Relocate()
					B.Relocate()
				if("run")
					world << "<b>[A] has ran from the battle against [B]</b>"
			if(!B.client) del(B) // if nobody is posessing it, delete it
			del(src)

		LogOutBattle(mob/A, mob/B) // A is the person who was either deleted or logged out
			B.loc = locate(B.lastx,B.lasty,B.lastz)
			B.inbattle = 0
			B.lock = 0
			world << "<b>[A] has logged out of battle against [B].</b>"
			B.Regenerate()
			B.Relocate()
			if(!B.client) del(B)
			del(src)







